/*
   Chapter14Tables.prg
   A sample dBL program from 
   The dBASE Book
   by Kenneth J. Mayer. 
   Program copyright 2005-2012. 
   Permission granted for use as a learning tool for dBASE Plus.

   Sample from: Chapter 14  
   Create tables for the purpose of showing how to use stock form controls in
   dBASE Plus.
*/

// Check to see if the table exists:
if file( "AddressBook.dbf" )
   // delete it so we can "start over":
   drop table AddressBook
endif

// localSQL create table command:
create table AddressBook (;
             FirstName      char( 15 ),;
             LastName       char( 20 ),;
             Address1       char( 25 ),;
             Address2       char( 25 ),;
             City           char( 30 ),;
             StateProv      char(  3 ),;
             PostalCode     char( 10 ),;
             Country        char(  3 ),;
             Phone          char( 14 ),;
             Business       boolean,;
             Notes          blob( 10, 1 ),;
             Birthday       date,;
             FavoriteFlavor char( 25 );
                          )

// OODML method of creating an index:
local i 
i = new DBFIndex()
i.expression := "upper( LastName )+upper( FirstName )"
i.indexName  := "Name"
_app.databases[1].createIndex( "AddressBook", i )

// XDML is faster for some things:
use AddressBook
// first row:
append blank
replace FirstName      with "Fred"
replace LastName       with "Smith"
replace Address1       with "1234 First Street"
replace City           with "Testville"
replace StateProv      with "CA"
replace PostalCode     with "99999-9999"
replace Country        with "USA"
replace Phone          with "(999) 999-9999"
replace Business       with false
replace Notes          with "Fred is an old family friend, his wife's name is Judy. No children at this time."
replace Birthday       with {03/31/1963}
replace FavoriteFlavor with "Chocolate"
// Second row
append blank
replace FirstName      with "Joe"
replace LastName       with "Jones"
replace Address1       with "111 Main St."
replace Address2       with "Box 5678"
replace City           with "Somecity"
replace StateProv      with "OR"
replace PostalCode     with "88888-8888"
replace Country        with "USA"
replace Phone          with "(888) 888-9999"
replace Business       with true
replace Notes          with "Joe's business needs some help, and he contacted me ..."
replace Birthday       with {07/15/1960}
replace FavoriteFlavor with "Macadamia Nut"
// close the table
use

// ----- create two lookup tables, without all the data that
//       might normally be in them:

if file( "StateProv.dbf" )
   // delete it so we can "start over":
   drop table StateProv
endif

create table StateProv (;
             Code      char(3),;
             StateProv char( 30 ) )

i = new DBFIndex()
i.expression := "upper( StateProv )"
i.indexName  := "StateProv"
_app.databases[1].createIndex( "StateProv", i )

use StateProv
append blank
replace Code      with "CA"
replace StateProv with "California"
append blank
replace code      with "OR"
replace StateProv with "Oregon"
append blank
replace code      with "WA"
replace StateProv with "Washington"
use
// normally we would add all 50 states in the US, possibly
// the provinces in Canada, etc. We're keeping it simple!


if file( "Country.dbf" )
   // delete it so we can "start over":
   drop table Country
endif

create table Country (;
             Code      char(3),;
             Country   char( 30 ) )

i = new DBFIndex()
i.expression := "upper( Country )"
i.indexName  := "Country"
_app.databases[1].createIndex( "Country", i )


use country
append blank
replace Code    with "USA"
replace Country with "United States of America"
append blank
replace Code    with "CAN"
replace Country with "Canada"
use
// as with the StateProv table, we're keeping this simple ...

// Phonebook table used for one example:
if file( "PhoneBook.dbf" )
   // delete it so we can "start over":
   drop table PhoneBook
endif

create table PhoneBook (;
             LastName  char(35),;
             FirstName char(30),;
             PhoneNumber char(15) )

i = new DBFIndex()
i.expression := "upper( LastName )"
i.indexName  := "LastName"
_app.databases[1].createIndex( "PhoneBook", i )

use Phonebook
generate 500
use


// end of program Chapter14Tables

