/*
   ProgressTest.prg
   A sample dBL program from 
   The dBASE Book
   by Kenneth J. Mayer. 
   Program copyright 2005-2012. 
   Permission granted for use as a learning tool for dBASE Plus.

   Sample from: Chapter 14
   A program to show how to use a Progress Bar with a table:
   This program uses local SQL (create table),
   XDML (USE, GENERATE), and OODML to accomplish the task 
   needed. 
*/
// Create a test table:
if file( "TestProgress.dbf" )
   drop table "TestProgress"
endif

create table TestProgress ( ;
             TestOne   char(10),;
             TestTwo   char(10),;
             TestThree char(10) )

// we will open the table using XDML for
// a moment, generate some data, and then
// close the table:
use TestProgress
generate 200
use

// Now we have data, we're going back to OODML:
q         = new query()
q.sql    := "select * from TestProgress"
q.active := true


// we need to open the form:
set procedure to ProgressForm.wfm additive
f = new ProgressFormForm()
// the lower end of the progress bar's range:
f.Progress1.rangeMin := 1
// the upper end, in this case the number of 
// rows in the table:
f.Progress1.rangeMax := q.rowset.count()
// the current value of the progress bar:
f.Progress1.value    := 1
// open the form:
f.open()


// create a simple counter:
n = 0

// loop through the table:
do while not q.rowset.endOfSet
   // increment the counter:
   n++

   // update the progress bar:
   f.Progress1.value := n

   // do something with the data in the table, in this
   // case we're going to copy the value in field
   // TestOne to field TestTwo:
   q.rowset.fields["TestTwo"].value := ;
     q.rowset.fields["TestOne"].value
   // because this is fast, let's tell the computer
   // to wait just a moment:
   inkey( .01 )

   // next row in the rowset:
   q.rowset.next()
enddo


// cleanup:
q.active := false
release object q
f.close()
f.release()
close procedure ProgressForm.wfm
drop table TestProgress

